# Table of Contents

- [impacts](<./impacts.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Impacts](<./Impacts.md>)
  - [Implied and Custom Impacts of Transformations](<./Impacts/Implied-and-Custom-Impacts-of-Transformations.md>)
  - [Impacts Execution Order](<./Impacts/Impacts-Execution-Order.md>)
  - [Impact Type Classification Rules](<./Impacts/Impact-Type-Classification-Rules.md>)
  - [Was this page helpful?](<./Impacts/Was-this-page-helpful.md>)
